@@ -4,7 +4,7 @@ use warnings;
 use base qw{Package::New Package::Role::ini};
 use Power::Outlet;
 
-our $VERSION='0.33';
+our $VERSION='0.34';
 our $PACKAGE=__PACKAGE__;
 
 =head1 NAME
@@ -75,7 +75,7 @@ sub section {
   $self->{'section'} = shift if @_;
   die(qq{Error: Package: $PACKAGE: Object property "section" required.\n})
     unless $self->{'section'};
-  die(sprintf(qq{Error: Package: $PACKAGE: Section "%s" does not exists in file "%s". Expected one of %s.\n}, $self->{'section'}, $self->ini_file, join(", ", map {qq{"$_"}} $self->ini->Sections)))
+  die(sprintf(qq{Error: Package: $PACKAGE: Section "%s" does not exist in file "%s". Expected one of %s.\n}, $self->{'section'}, $self->ini_file, join(", ", map {qq{"$_"}} $self->ini->Sections)))
     unless $self->ini->SectionExists($self->{'section'});
   return $self->{'section'};
 }
